@@ -11,7 +11,7 @@ This module only works with Python 2.0 since all string parameters
 are assumed to be Unicode objects and string methods are used instead
 string module.
 
-$Id: forms.py,v 1.35 2003/12/23 15:11:19 michael Exp $
+$Id: forms.py,v 1.36 2006/03/10 15:43:15 michael Exp $
 """ 
 
 __version__ = '0.15.0'
@@ -215,9 +215,13 @@ class Field:
     """returns default value"""
     return default or self.__dict__.get('default','')
 
+  def titleHTML(self,title):
+    """HTML output of default."""
+    return escapeHTML(title or self.text).encode(self.charset)
+
   def _defaultHTML(self,default):
     """HTML output of default."""
-    return escapeHTML(self._defaultValue(default).encode(self.charset))
+    return escapeHTML(self._defaultValue(default)).encode(self.charset)
 
   def valueHTML(self):
     """
@@ -261,7 +265,7 @@ class Textarea(Field):
     return self.inputHTMLTemplate % (
       '<textarea %stitle="%s" name="%s" %s rows="%d" cols="%d">%s</textarea>' % (
         self.idAttrStr(id_value),
-        (title or self.text).encode(self.charset),
+        self.titleHTML(title),
 	self.name,
 	self._accessKeyAttr(),
 	self.rows,self.cols,
@@ -299,7 +303,7 @@ class Input(Field):
     return self.inputHTMLTemplate % (
 	'<input %stitle="%s" name="%s" %s maxlength="%d" size="%d" value="%s">' % (
 	self.idAttrStr(id_value),
-        (title or self.text).encode(self.charset),
+        self.titleHTML(title),
         self.name,
         self._accessKeyAttr(),
         self.maxLen,
@@ -331,7 +335,7 @@ class HiddenInput(Input):
     return self.inputHTMLTemplate % (
 	'<input type="hidden" %stitle="%s" name="%s" %s  value="%s">%s' % (
 	  self.idAttrStr(id_value),
-          (title or self.text).encode(self.charset),
+          self.titleHTML(title),
           self.name,
           self._accessKeyAttr(),
           default_html,
@@ -361,7 +365,7 @@ class File(Input):
     return self.inputHTMLTemplate % (
 	'<input type="file" %stitle="%s" name="%s" %s maxlength="%d" size="%d" accept="%s" value="%s">' % (
 	self.idAttrStr(id_value),
-        (title or self.text).encode(self.charset),
+        self.titleHTML(title),
         self.name,
         self._accessKeyAttr(),
         self.maxLen,
@@ -382,7 +386,7 @@ class Password(Input):
     return self.inputHTMLTemplate % (
       '<input %stitle="%s" name="%s" %s maxlength="%d" size="%d" type="password" value="%s">' % (
 	self.idAttrStr(id_value),
-        (title or self.text).encode(self.charset),
+        self.titleHTML(title),
         self.name,
         self._accessKeyAttr(),
         self.maxLen,
@@ -464,7 +468,7 @@ class Radio(Field):
           %s
         >%s<br>""" % (
           self.idAttrStr(id_value),
-          (title or self.text).encode(self.charset),
+          self.titleHTML(title),
           self.name.encode(self.charset),
           self._accessKeyAttr(),
           optionValue,
@@ -529,7 +533,7 @@ class Select(Radio):
   def inputHTML(self,default=None,id_value=None,title=None):
     s = ['<select %stitle="%s" name="%s" %s  size="%d" %s>' % (
       self.idAttrStr(id_value),
-      (title or self.text).encode(self.charset),
+      self.titleHTML(title),
       self.name,
       self._accessKeyAttr(),
       self.size,
@@ -582,7 +586,7 @@ class Checkbox(Field):
     return self.inputHTMLTemplate % (
       '<input type="checkbox" %stitle="%s" name="%s" %s value="%s"%s>' % (
         self.idAttrStr(id_value),
-        (title or self.text).encode(self.charset),
+        self.titleHTML(title),
         self.name,
 	self._accessKeyAttr(),
 	self._defaultValue(default),' checked'*(checked)
@@ -613,7 +617,7 @@ class Keygen(Field):
     return self.inputHTMLTemplate % (
       '<keygen %stitle="%s" name="%s" %s challenge="%s">' % (
         self.idAttrStr(id_value),
-        (title or self.text).encode(self.charset),
+        self.titleHTML(title),
         self.name,
         self._accessKeyAttr(),
         challenge
