@@ -6,7 +6,7 @@ This module is distributed under the terms of the
 GPL (GNU GENERAL PUBLIC LICENSE) Version 2
 (see http://www.gnu.org/copyleft/gpl.html)
 
-$Id: helper.py,v 1.10 2003/11/22 20:51:08 michael Exp $
+$Id: helper.py,v 1.11 2008/07/26 12:27:56 michael Exp $
 """
 
 __version__ = '0.3.0'
@@ -164,8 +164,7 @@ class AcceptCharsetDict(AcceptHeaderDict):
   def __init__(self,envKey='HTTP_ACCEPT_CHARSET',env=None,defaultValue='utf-8'):
     AcceptHeaderDict.__init__(self,envKey,env,defaultValue)
     # Special treating of ISO-8859-1 charset to be compliant to RFC2616
-    if not self.data.has_key('iso-8859-1'):
-      self.data['iso-8859-1'] = 1.0
+    self.data['iso-8859-1'] = self.data.get('iso-8859-1',self.data.get('*',1.0))
     return # AcceptCharsetDict.__init__()
 
   def preferred(self):
